Pricing Elasticity Analysis: How does a price change impact my bottom line?
Author: Content Engineering - Stephen Wagner
Description: This Starter Kit will guide you through how you can use the A/B testing tools within Alteryx to answer "How does a price change impact my bottom line?" and similar questions.

An important step in running an A/B test is to match control and treatment units properly.
Matching units properly will allow you to control for differences between units and compare "apples to apples" as best as possible.
This guided workflow will demonstrate how to match control and treatment stores to use when analyzing which facial price performed the best.

Use keyboard arrow keys to progress through walkthrough. Press Esc to end walkthrough.

For best viewing experience, please move the Results view underneath the Configuration view